@@ -21,6 +21,8 @@
 #include "c2s.h"
 
 #include <stringprep.h>
+#include <string.h>
+#include <ctype.h>
 
 static sig_atomic_t c2s_shutdown = 0;
 sig_atomic_t c2s_lost_router = 0;
@@ -556,12 +558,9 @@ static int _c2s_sx_sasl_callback(int cb, void *arg, void **res, sx_t s, void *cb
         case sx_sasl_cb_CHECK_MECH:
             mech = (char *)arg;
 
-            i=0;
-            while(i<sizeof(mechbuf) && mech[i]!='\0') {
-                mechbuf[i]=tolower(mech[i]);
-                i++;
-            }
-            mechbuf[i]='\0';
+            strncpy(mechbuf, mech, sizeof(mechbuf));
+            mechbuf[sizeof(mechbuf)-1]='\0';
+            for(i = 0; mechbuf[i]; i++) mechbuf[i] = tolower(mechbuf[i]);
 
             /* get host for request */
             host = xhash_get(c2s->hosts, s->req_to);
@@ -621,7 +620,9 @@ static void _c2s_time_checks(c2s_t c2s) {
             xhv.sess_val = &sess;
             xhash_iter_get(c2s->sessions, NULL, NULL, xhv.val);
 
-            if(c2s->io_check_idle > 0 && sess->s && now > sess->last_activity + c2s->io_check_idle) {
+            if(!sess->s) continue;
+
+            if(c2s->io_check_idle > 0 && now > sess->last_activity + c2s->io_check_idle) {
                 log_write(c2s->log, LOG_NOTICE, "[%d] [%s, port=%d] timed out", sess->fd->fd, sess->ip, sess->port);
 
                 sx_error(sess->s, stream_err_HOST_GONE, "connection timed out");
@@ -780,17 +781,6 @@ JABBER_MAIN("jabberd2c2s", "Jabber 2 C2S", "Jabber Open Source Server: Client to
 
     c2s->sx_env = sx_env_new();
 
-#ifdef USE_WEBSOCKET
-    /* possibly wrap in websocket */
-    if(c2s->websocket) {
-        sx_env_plugin(c2s->sx_env, sx_websocket_init, c2s->http_forward);
-    }
-#else
-    if(c2s->http_forward) {
-        log_write(c2s->log, LOG_ERR, "httpforward available only with websocket support built-in");
-    }
-#endif
-
 #ifdef HAVE_SSL
     /* get the ssl context up and running */
     if(c2s->local_pemfile != NULL) {
@@ -811,10 +801,25 @@ JABBER_MAIN("jabberd2c2s", "Jabber 2 C2S", "Jabber Open Source Server: Client to
     }
 #endif
 
+#ifdef USE_WEBSOCKET
+    /* possibly wrap in websocket */
+    if(c2s->websocket) {
+        sx_env_plugin(c2s->sx_env, sx_websocket_init, c2s->http_forward);
+    }
+#else
+    if(c2s->websocket) {
+        log_write(c2s->log, LOG_ERR, "websocket support not built-in - not enabling");
+    }
+    if(c2s->http_forward) {
+        log_write(c2s->log, LOG_ERR, "httpforward available only with websocket support built-in");
+    }
+#endif
+
 #ifdef HAVE_LIBZ
     /* get compression up and running */
-    if(c2s->compression)
+    if(c2s->compression) {
         sx_env_plugin(c2s->sx_env, sx_compress_init);
+    }
 #endif
 
     /* get stanza ack up */
