@@ -182,6 +182,8 @@ void _out_dns_mark_bad(conn_t out) {
             bad = (dnsres_t) calloc(1, sizeof(struct dnsres_st));
             bad->key = ipport;
             xhash_put(out->s2s->dns_bad, ipport, bad);
+        } else {
+            free(ipport);
         }
         bad->expiry = time(NULL) + out->s2s->dns_bad_timeout;
     }
@@ -415,6 +417,10 @@ int out_route(s2s_t s2s, const char *route, int routelen, conn_t *out, int allow
     from_len = c - route;
     c++;
     c_len = routelen - (c - route);
+    if (c_len > 1023) {
+        /* domain name too long */
+        return -1;
+    }
     dkey = strndup(c, c_len);
 
     log_debug(ZONE, "trying to find connection for '%s'", dkey);
@@ -538,14 +544,24 @@ int out_route(s2s_t s2s, const char *route, int routelen, conn_t *out, int allow
             for (i = 0; i < s2s->origin_nips; i++) {
                 // only bother with mio_connect if the src and dst IPs are of the same type
                 if ((ip_is_v6 && (strchr(s2s->origin_ips[i], ':') != NULL)) ||          // both are IPv6
-                            (! ip_is_v6 && (strchr(s2s->origin_ips[i], ':') == NULL)))  // both are IPv4
-                    (*out)->fd = mio_connect(s2s->mio, port, ip, s2s->origin_ips[i], _out_mio_callback, (void *) *out);
+                            (! ip_is_v6 && (strchr(s2s->origin_ips[i], ':') == NULL))) {// both are IPv4
 
-                if ((*out)->fd != NULL) break;
+                    (*out)->fd = mio_connect(s2s->mio, port, ip, s2s->origin_ips[i], _out_mio_callback, (void *) *out);
+                    if ((*out)->fd != NULL) break;
+                    log_write(s2s->log, LOG_NOTICE, "[%d] [%s, port=%d] [origin: %s] mio_connect error: %s (%d)", -1, (*out)->ip, (*out)->port, s2s->origin_ips[i], MIO_STRERROR(MIO_ERROR), MIO_ERROR);
+                }
+            }
+
+            /* fallback to connecting using local.ip */
+            if ((*out)->fd == NULL) {
+                (*out)->fd = mio_connect(s2s->mio, port, ip, s2s->local_ip, _out_mio_callback, (void *) *out);
+                if ((*out)->fd == NULL) {
+                    log_write(s2s->log, LOG_NOTICE, "[%d] [%s, port=%d] [local: %s] mio_connect error: %s (%d)", -1, (*out)->ip, (*out)->port, s2s->local_ip, MIO_STRERROR(MIO_ERROR), MIO_ERROR);
+                }
             }
 
             if ((*out)->fd == NULL) {
-                log_write(s2s->log, LOG_NOTICE, "[%d] [%s, port=%d] mio_connect error: %s (%d)", -1, (*out)->ip, (*out)->port, MIO_STRERROR(MIO_ERROR), MIO_ERROR);
+                log_write(s2s->log, LOG_NOTICE, "[%d] [%s, port=%d] unable to connect host", -1, (*out)->ip, (*out)->port);
 
                 _out_dns_mark_bad(*out);
 
@@ -619,12 +635,9 @@ int out_packet(s2s_t s2s, pkt_t pkt) {
             (pkt->to->domain != NULL) &&
             (s2s_domain_in_whitelist(s2s, pkt->to->domain) == 0)) {
         log_write(s2s->log, LOG_NOTICE, "sending a packet to domain not in the whitelist, dropping it");
-        if (pkt->to != NULL)
-            jid_free(pkt->to);
-        if (pkt->from != NULL)
-            jid_free(pkt->from);
-        if (pkt->nad != NULL)
-            nad_free(pkt->nad);
+        jid_free(pkt->to);
+        jid_free(pkt->from);
+        nad_free(pkt->nad);
         free(pkt);
 
         return 0;
@@ -1197,6 +1210,7 @@ void dns_resolve_domain(s2s_t s2s, dnscache_t dns) {
         /* shortcut resolution failure */
         query->expiry = time(NULL) + 99999999;
         out_resolve(query->s2s, dns->name, query->results, query->expiry);
+        free(query);
         return;
     }
     query->name = name;
